Struct Client

pub struct Client { /* private fields */ }
A proxy to a client.

Implementations

Source

impl Client

pub fn add_listener_local(&self) -> ClientListenerLocalBuilder<'_>

pub fn error(&self, id: u32, res: i32, message: &str)

Send an error to the client.

Permissions

Requires W and X permissions on the client.

Parameters

id: The global id to report the error on
res: An errno style error code message: An error string

pub fn error_cstr(&self, id: u32, res: i32, message: &CStr)

Send an error to the client.

Permissions

Requires W and X permissions on the client.

Parameters

id: The global id to report the error on
res: An errno style error code message: An error string

pub fn update_properties(&self, properties: &DictRef)

Update the client’s properties.

Permissions

Requires W and X permissions on the client.

pub fn get_permissions(&self, index: u32, num: u32)

Get the client’s permissions.

A permissions event will be emitted.

Permissions

Requires W and X permissions on the client.

Parameters

index: The first index to query, 0 for first
num: The maximum number of items to get

pub fn update_permissions(&self, permissions: &[Permission])

Manage the permissions of the global objects for this client.

Update the permissions of the global objects using the provided slice.

Globals can use the default permissions or can have specific permissions assigned to them.

Permissions

Requires W and X permissions on the client.