pub struct ClientListener { /* private fields */ }Expand description
An owned listener for client events.
This is created by ClientListenerLocalBuilder and will receive events as long as it is alive.
When this gets dropped, the listener gets unregistered and no events will be received by it.